@@ -1,7 +1,8 @@
 import sys
 
-from PyQt5.QtWidgets import QApplication
+from qtpy.QtWidgets import QApplication
 
+import napari
 from napari_allencell_annotator.controller.main_controller import MainController
 
 
@@ -12,8 +13,9 @@ class App(QApplication):
 
     def __init__(self, sys_argv):
         super(App, self).__init__(sys_argv)
-
-        MainController()
+        self.viewer = napari.Viewer()
+        self.main = MainController(self.viewer)
+        self.viewer.window.add_dock_widget(self.main, area="right")
 
 
 if __name__ == "__main__":
